dopes.equipment_control.mecom API documentation
Description: The package consists of 3 files …

# Module `dopes.equipment_control.mecom`

The package consists of 3 files.

commands.py contains a dictionary parameters which can be get/set exceptions.py defines the error thrown by this pockage mecom.py contains the communication logic

## Sub-modules

`dopes.equipment_control.mecom.commands`

  Definitions of command and error codes as stated in the MeCom protocol specification. Documents can be found at …

`dopes.equipment_control.mecom.exceptions`

  This file contains some custom expceptions.

`dopes.equipment_control.mecom.mecom`

  " The magic happens in this file.